@@ -1,13 +1,14 @@
 package Module::Dependency::Grapher;
-use strict;
+
 use Module::Dependency::Info;
+use GD;
 
 use vars qw/$VERSION @TIERS %LOOKUP %COLOURS
 @numElements $colWidth $rowHeight
 $nOffset $eOffset $sOffset $wOffset
 /;
 
-($VERSION) = ('$Revision: 1.22 $' =~ /([\d\.]+)/ );
+($VERSION) = ('$Revision: 1.12 $' =~ /([\d\.]+)/ );
 
 %COLOURS = (
 	type => [0,0,0],
@@ -21,15 +22,13 @@ $nOffset $eOffset $sOffset $wOffset
 	white => [255,255,255],
 );
 
-### PUBLIC INTERFACE FUNCTIONS
-
 sub setIndex {
 	Module::Dependency::Info::setIndex( @_ );
 }
 
 sub makeText {
 	my ($kind, $seeds, $filename, $options) = @_;
-	my ($maxitems, $pushed) = _makeCols($kind, $seeds, $options->{IncludeRegex}, $options->{ExcludeRegex});
+	my ($maxitems, $pushed) = _makeCols($kind, $seeds);
 	my $imgtitle = $options->{'Title'} || 'Dependency Tree';
 
 	# print the text out
@@ -56,7 +55,7 @@ sub makeText {
 
 sub makeHtml {
 	my ($kind, $seeds, $filename, $options) = @_;
-	my ($maxitems, $pushed) = _makeCols($kind, $seeds, $options->{IncludeRegex}, $options->{ExcludeRegex});
+	my ($maxitems, $pushed) = _makeCols($kind, $seeds);
 	
 	my %rowclasses = (
 		parent => 'MDGraphParent',
@@ -91,53 +90,15 @@ sub makeHtml {
 		print( HTML qq(<tr><td class="$rowclasses{$type}">$notes{$type}</td><td class="$rowclasses{$type}">), join(', ', sort { $a cmp $b } @{$TIERS[$_]}), "</td></tr>\n" );
 	}
 	print HTML "</table>\n</div>\n";
-
-	# create the imagemap
-	my $rv = 1;
-	if ( $options->{ImageMap} ) {
-		my $code = $options->{ImageMapCode} || \&_imgmapdefault;
-		my $frmt = $options->{HrefFormat} || '';
-		_imageDimsSet();
-		if ($maxitems < 8) {
-			$rowHeight = 8*$rowHeight*1.5 / $maxitems;
-		} elsif ($maxitems < 16) {
-			$rowHeight = 16*$rowHeight / $maxitems;
-		}
-		_packObjects( $rowHeight * $maxitems, 5 );
-		my $str = qq(<map name="dependence">\n);
-		foreach my $v (values %LOOKUP) { $str .= $code->($v, $frmt); }
-		$str .= qq(</map>\n);
-				
-		if (lc($options->{ImageMap}) eq 'print') {
-			print HTML $str;
-		} else {
-			$rv = $str;
-		}
-	}
-
 	close HTML;
-
-	return $rv;
-}
-
-sub _imgmapdefault {
-	my ($v, $frmt) = @_;
-	my $pack = $v->{'package'};
-	my $alt = "Root the dependency tree on '$pack'";
-	return qq(<!-- PACK $pack --><area href=") . sprintf($frmt, $pack) . q(" shape="rect" coords=")
-	. int($v->{'x'} -3) . ',' . int($v->{'y'} -1) . ',' . int($v->{'x2'} +3) . ',' . int($v->{'y'} +9)
-	. qq(" alt="$alt" title="$alt" />\n);
 }
 
 sub makeImage {
-	require GD;
-	import GD;
-
 	my ($kind, $seeds, $filename, $options) = @_;
 	my $type = uc($options->{'Format'}) || 'PNG';
 	my $imgtitle = $options->{'Title'} || 'Dependency Chart';
 	
-	my ($maxitems, $pushed) = _makeCols($kind, $seeds, $options->{IncludeRegex}, $options->{ExcludeRegex});
+	my ($maxitems, $pushed) = _makeCols($kind, $seeds);
 	_imageDimsSet();
 
 	LOG( "Making image to $filename" );
@@ -161,21 +122,20 @@ sub makeImage {
 	$im->colorAllocate( 255,255,255 );
 	while (my ($k, $v) = each %COLOURS) { $colours->{ $k } = $im->colorAllocate( @$v ); }
 	
-	_packObjects($imgHeight, 5); # gdTinyFont has 5 pixel wide characters
+	_packObjects($imgHeight);
 	_linkObjects($im, $colours);
 	_labelObjects($im, $colours);
 	
 	# add legend and prettiness
 	TRACE( "Drawing legend etc" );
-	$im->string(gdMediumBoldFont(), 5, 3, $imgtitle, $colours->{'title1'});
-	$im->string(gdSmallFont(), 5, 17, "Grapher.pm $VERSION - " . localtime(), $colours->{'title1'}) unless $options->{'NoVersion'};
+	$im->string(gdMediumBoldFont, 5, 3, $imgtitle, $colours->{'title1'});
+	$im->string(gdSmallFont, 5, 17, "Grapher.pm $VERSION - " . localtime(), $colours->{'title1'}) unless $options->{'NoVersion'};
 	
 	_drawLegend( $im, $colours, $realImgWidth - 160 - $eOffset, 3 ) unless $options->{'NoLegend'};
 
 	TRACE( "Printing image" );
 	local *IMG;
 	open(IMG, "> $filename") or die("Can't open $filename for image write: $!");
-	binmode( IMG );
 	if ($type eq 'GIF') { print IMG $im->gif;
 	} elsif ($type eq 'PNG') { print IMG $im->png;
 	} elsif ($type eq 'JPG') { print IMG $im->jpg;
@@ -184,76 +144,17 @@ sub makeImage {
 	close IMG;
 }
 
-# SVG has an origin at the top-left, like GD, and an SVG image can use unitless coordinates: so we can borrow a lot from makeImage()
-sub makeSvg {
-	require SVG;
-	import SVG;
-
-	my ($kind, $seeds, $filename, $options) = @_;
-	my $imgtitle = $options->{'Title'} || 'Dependency Chart';
-	
-	my ($maxitems, $pushed) = _makeCols($kind, $seeds, $options->{IncludeRegex}, $options->{ExcludeRegex});
-	_imageDimsSet();
-
-	LOG( "Making SVG to $filename" );
-	
-	if ($maxitems < 8) {
-		$rowHeight = 8*$rowHeight*1.5 / $maxitems;
-	} elsif ($maxitems < 16) {
-		$rowHeight = 16*$rowHeight / $maxitems;
-	}
-	
-	my $imgWidth = $colWidth * (scalar(@TIERS) < 3 ? 3 : scalar(@TIERS));
-	my $imgHeight = $rowHeight * $maxitems;
-	
-	my $realImgWidth = $imgWidth + $wOffset + $eOffset;
-	my $realImgHeight = $imgHeight + $nOffset + $sOffset;
-	LOG( "Rows are $rowHeight px, maxitems is $maxitems, image is $realImgWidth * $realImgWidth" );
-
-	my $im = new SVG('viewBox' => ('0 0 '.($imgWidth+$wOffset+$eOffset).' '.($imgHeight+$nOffset+$sOffset)), 'preserveAspectRatio' => 'xMidYMid', '-indent' => "\t");
-
-	# set up image object
-	my $colours;
-	while (my ($k, $v) = each %COLOURS) { $colours->{ $k } = sprintf( '#%2.2x%2.2x%2.2x', @$v ); }
-	
-	$im->rectangle( 'x' => 0, 'y' => 0, 'width' => ($imgWidth+$wOffset+$eOffset), 'height' => ($imgHeight+$nOffset+$sOffset), stroke => $colours->{'black'}, fill => 'none' );
-	_packObjects($imgHeight, 5);
-	_linkObjects($im, $colours);
-
-	# are things clickable? Bit of a kludge, this
-	$colours->{'_HREF_FORMAT'} = $options->{'HrefFormat'};
-	_labelObjects($im, $colours);
-	delete $colours->{'_HREF_FORMAT'};
-	
-	# add legend and prettiness
-	TRACE( "Drawing legend etc" );
-
-	$im->text('x' => 5, 'y' => 12, 'fill' => $colours->{'title1'}, 'style' => { 'font-size' => '12px' })->cdata($imgtitle);
-	$im->text('x' => 5, 'y' => 23, 'fill' => $colours->{'title1'}, 'style' => { 'font-size' => '9px' })->cdata("Grapher.pm $VERSION - " . localtime()) unless $options->{'NoVersion'};
-	_drawLegend( $im, $colours, $realImgWidth - 160 - $eOffset, 3 ) unless $options->{'NoLegend'};
-	
-	$im->title(id=>'document-title')->cdata($imgtitle);
-	$im->desc(id=>'document-desc')->cdata('This image shows dependency relationships between perl programs and modules');
-
-	TRACE( "Printing SVG" );
-	local *IMG;
-	open(IMG, "> $filename") or die("Can't open $filename for image write: $!");
-	print IMG $im->xmlify;
-	close IMG;
-}
-
 sub makePs {
-	require PostScript::Simple;
-	
 	my ($kind, $seeds, $filename, $options) = @_;
 	my $imgtitle = $options->{'Title'} || 'Dependency Chart';
 	my $eps = ( uc($options->{'Format'}) eq 'PS') ? 0 : 1;
 	my $colour = exists( $options->{'Colour'} ) ? $options->{'Colour'} : 1;
 	my $font = $options->{'Font'} || 'Helvetica';
 	
-	my ($maxitems, $pushed) = _makeCols($kind, $seeds, $options->{IncludeRegex}, $options->{ExcludeRegex});
+	my ($maxitems, $pushed) = _makeCols($kind, $seeds);
 	_psDimsSet();
 
+	require PostScript::Simple;
 	LOG( "Making postscript to $filename" );
 
 	if ($maxitems < 8) {
@@ -275,7 +176,7 @@ sub makePs {
 	$p->setlinewidth(0.5);
 	$p->setfont( $font, 9 );
 	
-	_packObjects($imgHeight, 5.5);
+	_packObjects($imgHeight);
 	_linkObjects($p);
 	$p->setcolour( @{$COLOURS{'type'}} );
 	_labelObjects($p);
@@ -298,17 +199,12 @@ sub makePs {
 	$p->output( $filename );
 }
 
-### PRIVATE INTERNAL ROUTINES
-
 # algorithm which sorts dependencies into a series of generations (the @TIERS array)
 sub _makeCols {
-	my $kind = shift();
-	my $seeds = shift();
-	my $re = shift() || '';
-	my $xre = shift() || '';
+	my ($kind, $seeds) = @_;
 	
 	$kind = uc( $kind );
-	TRACE("makeCols: kind <$kind> re <$re> xre <$xre>");
+	TRACE("makeCols: kind <$kind>");
 	unless (ref( $seeds )) { $seeds = [ $seeds ]; }
 	unless ( $kind eq 'CHILD' || $kind eq 'PARENT' || $kind eq 'BOTH' ) { die("unrecognized sort of tree required: $kind - should be 'child', 'parent' or 'both'"); }
 	
@@ -336,11 +232,6 @@ sub _makeCols {
 
 				foreach my $dep ( @{$obj->{'depends_on'}} ) {
 					next if $seen{ $dep };
-					if ( ($re && $dep !~ m/$re/) || ($xre && $dep =~ m/$xre/) ) {	# if given regexps then apply filter
-						TRACE("  !..$dep skipped by regex");
-						$seen{ $dep } = 1;
-						next;
-					}
 					TRACE("  ...found $dep");
 					$LOOKUP{ $dep } = Module::Dependency::Info::getItem( $dep ) || do {$seen{ $dep } = 1; next;};
 					push (@$temp, $dep);
@@ -368,11 +259,6 @@ sub _makeCols {
 				
 				foreach my $dep ( @{$obj->{'depended_upon_by'}} ) {
 					next if $seen{ $dep };
-					if ( ($re && $dep !~ m/$re/) || ($xre && $dep =~ m/$xre/) ) {	# if given regexps then apply filter
-						TRACE("  !..$dep skipped by regex");
-						$seen{ $dep } = 1;
-						next;
-					}
 					TRACE("  ...found $dep");
 					$LOOKUP{ $dep } = Module::Dependency::Info::getItem( $dep ) || do {$seen{ $dep } = 1; next;};
 					push (@$temp, $dep);
@@ -400,7 +286,7 @@ sub _makeCols {
 
 # work out _where_ we're going to put the items
 sub _packObjects {
-	my ($imgHeight, $charwidth) = @_;
+	my ($imgHeight) = @_;
 	TRACE( "Packing objects" );
 	for my $x (0 .. $#TIERS) {
 		my $y = 0;
@@ -413,7 +299,7 @@ sub _packObjects {
 			unless ( exists $obj->{'x'} ) {
 				$obj->{'x'} = $cx;
 				$obj->{'y'} = $cy;
-				$obj->{'x2'} = $cx + 1 + $charwidth * length($obj->{'package'}); # gdTinyFont has characters 5 pixels wide
+				$obj->{'x2'} = $cx + 1 + 5 * length($obj->{'package'}); # gdTinyFont has characters 5 pixels wide
 			}
 			$y++;
 		}
@@ -450,25 +336,15 @@ sub _labelObjects {
 	}
 }
 
-# ! behaves differently for each image type
 sub _drawLegend {
 	my ($im, $colours, $x, $y) = @_;
-	my $type = ref($im);
-	
-	if ($type =~ m/^GD/) {
-		$im->rectangle( $x, $y, $x+138, $y+37, $colours->{'border'} );
-	} elsif ($type =~ m/SVG/) {
-		$im->rectangle( 'x' => $x, 'y' => $y, 'width' => 138, 'height' => 37, stroke => 'none', stroke => $colours->{'border'}, fill => 'none' );
-	}
+
+	$im->rectangle( $x, $y, $x+138, $y+37, $colours->{'border'} );
 	$x += 4;
 	$y += 3;
 	
 	_drawText( $im, $colours, $x, $y, 'Legend');
-	if ($type =~ m/^GD/) {
-		$im->line( $x, $y+8, $x+30, $y+8, $colours->{'type'} );
-	} elsif ($type =~ m/SVG/) {
-		$im->line( x1 => $x, y1 => $y+8, x2 => $x+30, y2 => $y+8, stroke => $colours->{'type'} );
-	}
+	$im->line( $x, $y+8, $x+30, $y+8, $colours->{'type'} );
 	$y += 12;
 	_drawLink( $im, $colours, $x+31, $y, 100+$x, $y);
 	_drawText( $im, $colours, $x, $y, 'Foo.pl');
@@ -493,49 +369,30 @@ sub _drawPsLegend {
 	$p->box( $x, $y-1, $x+120, $y+34 );
 }
 
-# ! behaves differently for each image type
 sub _drawText {
 	my ($im, $colours, $x, $y, $text) = @_;
-	my $type = ref($im);
-#	TRACE("_drawText for $type");
-
-	if ($type =~ m/^GD/) {
-		$im->string(gdTinyFont(), $x, $y, $text, $colours->{'type'});
-	} elsif ($type =~ m/^PostScript/) {
+	if (defined $colours ) {
+		$im->string(gdTinyFont, $x, $y, $text, $colours->{'type'});
+	} else {
 		$im->text($x, $y, $text);
-	} elsif ($type =~ m/^SVG/) {
-		if ($colours->{'_HREF_FORMAT'}) {
-			$im->anchor(-href => sprintf($colours->{'_HREF_FORMAT'}, $text))->text('x' => $x, 'y' => $y+5.5, 'fill' => $colours->{'type'}, 'style' => { 'font-size' => '8px', 'font-family' => 'Courier, Monaco, monospaced'})->cdata($text);
-		} else {
-			$im->text('x' => $x, 'y' => $y+5.5, 'fill' => $colours->{'type'}, 'style' => { 'font-size' => '8px', 'font-family' => 'Courier, Monaco, monospaced'})->cdata($text);
-		}
 	}
 }
 
-# ! behaves differently for each image type
 sub _drawLink {
 	my ($im, $colours, $xa, $ya, $xb, $yb) = @_;
-	my $type = ref($im);
-#	TRACE("_drawLink for $type");
 	
-	if ($type =~ m/^GD/) {
+	if (defined $colours) {
 		$im->line( $xa, $ya+3, $xb-3, $yb+3, $colours->{'links'} );
 		$im->rectangle( $xa, $ya+2, $xa+1, $ya+4, $colours->{'blob_from'} );
 		$im->rectangle( $xb-3, $yb+2, $xb-4, $yb+4, $colours->{'blob_to'} );
-	} elsif ($type =~ m/^PostScript/) {
-		$im->setlinewidth(0.22);
+	} else {
+		$im->setlinewidth(0.18);
 		$im->line( $xa, $ya+3, $xb-3, $yb+3, @{$COLOURS{'black'}} );
 		$im->setcolour( @{$COLOURS{'white'}} );
 		$im->circle( $xb-3, $yb+3, 1, 1);
 		$im->setcolour( @{$COLOURS{'black'}} );
 		$im->circle( $xa, $ya+3, 1, 1);
 		$im->circle( $xb-3, $yb+3, 1, 0);
-	} elsif ($type =~ m/^SVG/) {
-		$im->line( x1 => $xa, y1 => $ya+3, x2 => $xb-3, y2 => $yb+3, stroke => $colours->{'links'} );
-		$im->rectangle( 'x' => $xa, 'y' => $ya+2, 'width' => 2, 'height' => 2, stroke => 'none', fill => $colours->{'blob_from'} );
-		$im->rectangle( 'x' => $xb-4, 'y' => $yb+2, 'width' => 2, 'height' => 2, stroke => 'none', fill => $colours->{'blob_to'} );
-	} else {
-		die 'This indicates that the object model has changed somewhere. Should not happen.';
 	}
 }
 
@@ -566,7 +423,7 @@ sub LOG {}
 
 =head1 NAME
 
-Module::Dependency::Grapher - creates visual dependency charts and accessible text versions
+Module::Dependency::Graph - creates visual dependency charts and accessible text versions
 
 =head1 SYNOPSIS
 
@@ -605,10 +462,6 @@ See below for the options. See README.EXAMPLES too.
 
 As makeImage() but does it in PostScript or EPS. EPS is the default. See below for the options. See README.EXAMPLES too.
 
-=item Module::Dependency::Grapher::makeSvg( $kind, $seeds, $filename, $options );
-
-As makeImage() but does it in SVG. See below for the options. See README.EXAMPLES too.
-
 =item Module::Dependency::Grapher::makeText( $kind, $seeds, $filename, $options );
 
 Creates a plain-text rendition of the dependency heirarchy. As it's only ASCII it can't plot
@@ -639,10 +492,9 @@ can apply CSS to it. Typical fragment is:
 	</table>
 	</div>
 
-Parameters are as for makeImage(). 
+Parameters are as for makeImage()
 
-See below for options - especially the ImageMap (and related) options, which allows this method to return an HTML client-side
-imagemap. See README.EXAMPLES too.
+See below for options. See README.EXAMPLES too.
 
 =back
 
@@ -668,16 +520,6 @@ pretty standard thesedays though) Default is PNG.
 
 The makePs() method recognizes only 'EPS' or 'PS' as format options. Default is 'EPS'.
 
-=item IncludeRegex
-
-A regular expression use to filter the items displayed. If this is '::' for example then the output will only
-show dependencies that contain those characters.
-
-=item ExcludeRegex
-
-A regular expression use to filter the items displayed. If this is '::' for example then the output will B<not>
-show dependencies that contain those characters.
-
 =item NoLegend
 
 If true, don't print the 'legend' box/text
@@ -694,57 +536,16 @@ Used by makePs() only - if 1 it makes a colour image, if 0 it makes a greyscale
 
 sed by makePs() only. Set the font used in the drawing. Default is 'Helvetica'.
 
-=item ImageMap
-
-Used by makeHtml() only - if set to 'print' it will print a skeleton imagemap to the output file; if set to 'return' then the imagemap text
-is the return value of makeHtml() so that the caller can process the string further.
-
-An imagemap looks like this example, but you can change the href attributes using the HrefFormat option (see below) so that they match what your CGI
-program is expecting.
-
-	<map name="dependence">
-	<!-- PACK a --><area href="" shape="rect" coords="217,110,229,122" alt="Root dependency tree on a" title="Root dependency tree on a">
-	<!-- PACK x.pl --><area href="" shape="rect" coords="17,110,44,122" alt="Root dependency tree on x.pl" title="Root dependency tree on x.pl">
-	</map>
-
-If you want to totally change the format of each 'area' element see the ImageMapCode option below.
-
-Note that the href attributes are deliberately left empty, for users of the 'return' method to easily post-process the string. The PACK comment
-at the start of each line is provided to tell you what the package or scriptname is. The imagemap corresponds to the image that _would_
-be produced by makeImage() if it were given the same arguments.
-
-See the bundled 'cgidepend.plx' CGI program to see a use for this imagemap.
-
-=item ImageMapCode
-
-Used by makeHtml() only - must be a code reference. Called once for each 'area' required. The first argument is the package name
-that the 'area' corresponds to, 'Foo::Bar' or 'baz.pl' for example. The second argument is the current HrefFormat setting, but you
-may ignore that, seeing as you're going to be writing the entire element. The default coderef creates the 'area' elements as shown above
-and respects the HrefFormat option.
-
-=item HrefFormat
-
-Used by makeHtml() and makeSvg() only - default is ''. A sprintf() formatting string used to format the 'href'
-attribute in EACH 'area' element of the imagemap, or the href of the anchors in SVG output.
-E.g. '?myparam=%s' would create an href of '?myparam=Foo'.
-
-If empty (as is the default) then you get no clickable links in the SVG output.
-
 =back
 
 =head1 PREREQUISITES
 
-If you want to use the makePs() method you'll need PostScript::Simple installed.
-If you want to use the makeImage() method you'll need GD installed.
-If you want to use the makeSvg() method you'll need the SVG module.
-However, these modules are 'require'd as needed so you can quite happily use the makeText and makeHtml routines.
-
-=head1 SEE ALSO
-
-Module::Dependency and the README files.
+GD. If you want to use the makePs() method you'll need PostScript::Simple installed.
 
 =head1 VERSION
 
-$Id: Grapher.pm,v 1.22 2002/09/25 23:06:35 piers Exp $
+$Id: Grapher.pm,v 1.12 2002/01/21 15:40:13 piers Exp $
 
 =cut
+
+
